<?php

namespace Drupal\access_policy\Form;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Ajax\CloseDialogCommand;
use Drupal\Core\Ajax\HtmlCommand;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\access_policy\AccessRulePluginManager;
use Drupal\access_policy\Entity\AccessPolicyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Ajax\ReplaceCommand;

/**
 * The form for deleting rules associated with an access policy.
 *
 * @internal
 */
abstract class AccessRuleConfigureFormBase extends FormBase {

  use AccessRuleTableTrait;

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The access rules plugin manager.
   *
   * @var \Drupal\access_policy\AccessRulePluginManager
   */
  protected $accessRulePluginManager;

  /**
   * The access policy entity object.
   *
   * @var \Drupal\access_policy\Entity\AccessPolicyInterface
   */
  protected $accessPolicy;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, AccessRulePluginManager $access_rule_manager) {
    $this->entityTypeManager = $entity_type_manager;
    $this->accessRulePluginManager = $access_rule_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('plugin.manager.access_rule'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, AccessPolicyInterface $access_policy = NULL) {
    return $form;
  }

  /**
   * Ajax callback to close the modal and update the selected rules.
   *
   * @param array $form
   *   The form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current form state.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   An ajax response object.
   */
  public function ajaxSubmitCallback(array $form, FormStateInterface $form_state) {
    $response = new AjaxResponse();

    if (!$form_state::hasAnyErrors()) {
      $selected_rules_list = $this->buildAccessRuleTable($this->accessPolicy);
      $response->addCommand(new CloseDialogCommand());
      $response->addCommand(new HtmlCommand('#access-rules', $selected_rules_list));
    }
    // If there were errors then rebuild the form with the error messages.
    else {
      $response->addCommand(new ReplaceCommand('.access-rule-modal-form', $form));
    }
    return $response;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // @todo implement submitForm() method.
  }

  /**
   * Ajax callback to close the modal without changing any rules.
   *
   * @return \Drupal\Core\Ajax\AjaxResponse
   *   An ajax response object.
   */
  public function ajaxCancelCallback() {
    $response = new AjaxResponse();
    $response->addCommand(new CloseDialogCommand());
    return $response;
  }

}
