<?php

namespace Drupal\access_policy\Plugin\AccessPolicyType;

use Drupal\Core\Plugin\PluginBase;

/**
 * Class Access policy type base.
 */
abstract class AccessPolicyTypeBase extends PluginBase implements AccessPolicyTypeInterface {

  /**
   * {@inheritdoc}
   */
  public function shouldValidatePermission($op) {
    if (!empty($this->pluginDefinition['operations'][$op]['permission'])) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function shouldValidateRules($op) {
    if (!empty($this->pluginDefinition['operations'][$op]['rules'])) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getAllOperations() {
    return array_keys($this->pluginDefinition['operations']);
  }

  /**
   * {@inheritdoc}
   */
  public function supportsPermissions() {
    foreach ($this->pluginDefinition['operations'] as $restriction) {
      if (!empty($restriction['permission'])) {
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function supportsRules() {
    foreach ($this->pluginDefinition['operations'] as $restriction) {
      if (!empty($restriction['rules'])) {
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function shouldValidateTypeRules($op) {
    $operation = $this->pluginDefinition['operations'][$op];
    if (isset($operation['rules']) && is_array($operation['rules'])) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function getTypeRuleIds($op) {
    $operation = $this->pluginDefinition['operations'][$op];
    if (isset($operation['rules']) && is_array($operation['rules'])) {
      return $operation['rules'];
    }
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getTypeRules() {
    if (!empty($this->pluginDefinition['access_rules'])) {
      return $this->pluginDefinition['access_rules'];
    }
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function hasTypeRules() {
    if (!empty($this->pluginDefinition['access_rules'])) {
      return TRUE;
    }
    return FALSE;
  }

}
