<?php

namespace Drupal\access_policy\Plugin\AccessRule;

/**
 * Restrict content by comparing field values.
 *
 * This access rule uses a deriver that that creates access rules for all
 * fields. It allows the comparison of the entity field to either the current
 * user or to some static values.
 *
 * @AccessRule(
 *   id = "field_value",
 *   deriver = "Drupal\access_policy\Plugin\Derivative\FieldValueAccessRule",
 * )
 */
class FieldValue extends FieldValueBase {

  use AccessRuleFieldTrait;

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      "operator" => 'in',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function operators() {
    $operators = [
      'in' => [
        'title' => $this->t('Is equal to'),
        'method' => 'validateEquals',
      ],
      'not in' => [
        'title' => $this->t('Is not equal to'),
        'method' => 'validateNotEquals',
      ],
    ];

    return $operators;
  }

  /**
   * Simple equals comparison.
   *
   * @param mixed $value
   *   The field value.
   * @param array $values
   *   Array of comparison values.
   *
   * @return bool
   *   TRUE if any values match.
   */
  public function validateEquals($value, array $options) {
    if ($this->equals($value, $options)) {
      return TRUE;
    }
    return FALSE;
  }

  /**
   * Simple not equals comparison.
   *
   * @param mixed $value
   *   the field value.
   * @param array $values
   *   Array of comparison values.
   *
   * @return bool
   *   FALSE if any values match.
   */
  public function validateNotEquals($value, array $options) {
    if ($this->notEquals($value, $options)) {
      return TRUE;
    }
    return FALSE;
  }

}
