<?php

namespace Drupal\access_policy\Plugin\AccessRule;

/**
 * Restrict content by comparing field values.
 *
 * @AccessRule(
 *   id = "field_value_numeric",
 *   base_plugin_id = "field_value",
 *   field_types = {
 *     "integer",
 *     "decimal",
 *     "float",
 *     "list_integer",
 *     "list_float",
 *   },
 * )
 */
class FieldValueNumeric extends FieldValueBase {

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return parent::defaultConfiguration() + [
      "operator" => '=',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function operators() {
    $operators = [
      '<' => [
        'title' => $this->t('Is less than'),
        'method' => 'validateSimple',
      ],
      '<=' => [
        'title' => $this->t('Is less than or equal to'),
        'method' => 'validateSimple',
      ],
      '=' => [
        'title' => $this->t('Is equal to'),
        'method' => 'validateSimple',
      ],
      '!=' => [
        'title' => $this->t('Is not equal to'),
        'method' => 'validateSimple',
      ],
      '>' => [
        'title' => $this->t('Is greater than'),
        'method' => 'validateSimple',
      ],
      '>=' => [
        'title' => $this->t('Is greater than or equal to'),
        'method' => 'validateSimple',
      ],
    ];

    return $operators;
  }

  /**
   * Validate operators.
   *
   * @param mixed $value
   *   The entity value.
   * @param array $options
   *   The option values.
   *
   * @return bool
   *   TRUE if operator passes; FALSE otherwise.
   */
  public function validateSimple($value, array $options) {
    $op = $this->configuration['operator'];
    switch ($op) {
      case '=':
        return $this->equals($value, $options);

      case '!=':
        return $this->notEquals($value, $options);

      case '<':
        foreach ($options as $option) {
          if ($value < $option) {
            return TRUE;
          }
        }
        break;

      case '<=':
        foreach ($options as $option) {
          if ($value <= $option) {
            return TRUE;
          }
        }
        break;

      case '>':
        foreach ($options as $option) {
          if ($value > $option) {
            return TRUE;
          }
        }
        break;

      case '>=':
        foreach ($options as $option) {
          if ($value >= $option) {
            return TRUE;
          }
        }
        break;
    }

    return FALSE;
  }

}
